==> tecfy_core_package-1.0.46.tar.gz: lib/views/general/upgrade.page.dart <==
part of tecfy_core_client_package;

class UpgradePage extends StatefulWidget {
  final bool isRequired;
  const UpgradePage({Key? key, this.isRequired = false}) : super(key: key);

  @override
  _UpgradePageState createState() => _UpgradePageState();
}

class _UpgradePageState extends AppState<UpgradePage> {
  Future _onUpgrade() async {
    try {
      if (Platform.isAndroid) {
        if (await canLaunch(
            'market://details?id=co.tecfy.market.operation.android'))
          launch('market://details?id=co.tecfy.market.operation.android');
        else
          launch(
              'https://play.google.com/store/apps/details?id=co.tecfy.market.operation.android');
        // launch('https://appgallery.huawei.com/#/app/C103798333');
      } else if (Platform.isWindows) {
        if (await canLaunch('ms-windows-store://pdp/?ProductId=9NH85JN7QVZ6'))
          launch('ms-windows-store://pdp/?ProductId=9NH85JN7QVZ6');
        else
          launch('https://www.microsoft.com/store/apps/9NH85JN7QVZ6');
      } else if (Platform.isIOS) {
        launch(
            'https://apps.apple.com/us/app/tecfy-pos-operation/id1555474350');
      }
    } catch (err) {
      AppNavigator.showMessage(context, 'Error in Open Update Link',
          message:
              'Current Version ${kIsWeb ? 'Web' : Platform.isAndroid ? 'Android' : Platform.isWindows ? 'Windows' : Platform.isIOS ? 'iOS' : Platform.isLinux ? 'Linux' : Platform.isMacOS ? 'MacOS' : 'Unknown'} ${TecfyBasicApp.appVersion}');
    }
  }

  @override
  Widget build(BuildContext context) {
    return Material(
      child: Stack(
        children: [
          Center(
            child: Column(
              mainAxisAlignment: MainAxisAlignment.center,
              children: kIsWeb
                  ? [
                      Text(
                        trans('New Version Available'),
                        style: TextStyle(fontWeight: FontWeight.bold),
                      ),
                      MaterialButton(
                        onPressed: () {
                          html.window.location.reload();
                        },
                        child: Text(trans(
                            'Please Click here to Refresh the Page and Update')),
                      ),
                    ]
                  : [
                      Text(trans('New Version Available')),
                      MaterialButton(
                        onPressed: _onUpgrade,
                        child: Text(trans('Please Click here to Update')),
                      ),
                    ],
            ),
          ),
          Align(
              alignment: Alignment.bottomRight,
              child: Padding(
                  padding: EdgeInsets.all(10),
                  child: Text(
                      'Current Version ${kIsWeb ? 'Web' : Platform.isAndroid ? 'Android' : Platform.isWindows ? 'Windows' : Platform.isIOS ? 'iOS' : Platform.isLinux ? 'Linux' : Platform.isMacOS ? 'MacOS' : 'Unknown'} ${TecfyBasicApp.appVersion}'))),
          widget.isRequired
              ? Container()
              : Align(
                  alignment: Alignment.topLeft,
                  child: Padding(
                    padding: EdgeInsets.all(10),
                    child: IconButton(
                      icon: Icon(Icons.close),
                      onPressed: () => AppNavigator.pop(context),
                    ),
                  ),
                )
        ],
      ),
    );
  }
}

==> tecfy_core_package-1.1.6.tar.gz: lib/views/general/upgrade.page.dart <==
part of tecfy_core_client_package;

class UpgradePage extends StatefulWidget {
  final bool isRequired;
  const UpgradePage({Key? key, this.isRequired = false}) : super(key: key);

  @override
  _UpgradePageState createState() => _UpgradePageState();
}

class _UpgradePageState extends AppState<UpgradePage> {
  Future _onUpgrade() async {
    try {
      if (Platform.isAndroid) {
        if (await canLaunch(
            'market://details?id=co.tecfy.market.operation.android'))
          launch('market://details?id=co.tecfy.market.operation.android');
        else
          launch(
              'https://play.google.com/store/apps/details?id=co.tecfy.market.operation.android');
        // launch('https://appgallery.huawei.com/#/app/C103798333');
      } else if (Platform.isWindows) {
        if (await canLaunch('ms-windows-store://pdp/?ProductId=9NH85JN7QVZ6'))
          launch('ms-windows-store://pdp/?ProductId=9NH85JN7QVZ6');
        else
          launch('https://www.microsoft.com/store/apps/9NH85JN7QVZ6');
      } else if (Platform.isIOS) {
        launch(
            'https://apps.apple.com/us/app/tecfy-pos-operation/id1555474350');
      }
    } catch (err) {
      AppNavigator.showMessage(
          context, 'Error in Open Update Link', MessageType.error,
          message:
              'Current Version ${kIsWeb ? 'Web' : Platform.isAndroid ? 'Android' : Platform.isWindows ? 'Windows' : Platform.isIOS ? 'iOS' : Platform.isLinux ? 'Linux' : Platform.isMacOS ? 'MacOS' : 'Unknown'} ${TecfyBasicApp.appVersion}');
    }
  }

  @override
  Widget build(BuildContext context) {
    return Material(
      child: Stack(
        children: [
          Center(
            child: Column(
              mainAxisAlignment: MainAxisAlignment.center,
              children: kIsWeb
                  ? [
                      Text(
                        trans('New Version Available'),
                        style: TextStyle(fontWeight: FontWeight.bold),
                      ),
                      MaterialButton(
                        onPressed: () {
                          html.window.location.reload();
                        },
                        child: Text(trans(
                            'Please Click here to Refresh the Page and Update')),
                      ),
                    ]
                  : [
                      Text(trans('New Version Available')),
                      MaterialButton(
                        onPressed: _onUpgrade,
                        child: Text(trans('Please Click here to Update')),
                      ),
                    ],
            ),
          ),
          Align(
              alignment: Alignment.bottomRight,
              child: Padding(
                  padding: EdgeInsets.all(10),
                  child: Text(
                      'Current Version ${kIsWeb ? 'Web' : Platform.isAndroid ? 'Android' : Platform.isWindows ? 'Windows' : Platform.isIOS ? 'iOS' : Platform.isLinux ? 'Linux' : Platform.isMacOS ? 'MacOS' : 'Unknown'} ${TecfyBasicApp.appVersion}'))),
          widget.isRequired
              ? Container()
              : Align(
                  alignment: Alignment.topLeft,
                  child: Padding(
                    padding: EdgeInsets.all(10),
                    child: IconButton(
                      icon: Icon(Icons.close),
                      onPressed: () => AppNavigator.pop(context),
                    ),
                  ),
                )
        ],
      ),
    );
  }
}
